Examples
========

See the following examples for demonstrations
of how ``nengo_spa`` works.

.. toctree::

   examples/convolution
   examples/associative_memory
   examples/question
   examples/question_control
   examples/question_memory
   examples/spa_sequence
   examples/spa_sequence_routed
   examples/spa_parser
   examples/vocabulary_casting
